@@ -22,6 +22,8 @@ def install():
     # Install deps and init allo yml file
     AnsibleUtil.install_dependencies()
     TelemUtil.telem_start()
+    # Wait 2 seconds, waiting for node to be visible on teleport side
+    time.sleep(2)
 
     fileresult = "/tmp/install_result"
 
